diff --git a/core/modules/aggregator/config/optional/views.view.aggregator_rss_feed.yml b/core/modules/aggregator/config/optional/views.view.aggregator_rss_feed.yml
index 8e25d90d7ee7c756f373aa5e6f723903096c182e..1a165499449495a302256111e6aef68353c82526 100644
--- a/core/modules/aggregator/config/optional/views.view.aggregator_rss_feed.yml
+++ b/core/modules/aggregator/config/optional/views.view.aggregator_rss_feed.yml
@@ -36,7 +36,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/aggregator/config/optional/views.view.aggregator_sources.yml b/core/modules/aggregator/config/optional/views.view.aggregator_sources.yml
index 125454ff47d79238291a37aec3af91918b265ef1..7ddea89ed032b363802eacaae079b1e83a3f69fd 100644
--- a/core/modules/aggregator/config/optional/views.view.aggregator_sources.yml
+++ b/core/modules/aggregator/config/optional/views.view.aggregator_sources.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/block_content/config/optional/views.view.block_content.yml b/core/modules/block_content/config/optional/views.view.block_content.yml
index fbf02e49451b1835312c100500f3ed32d881c271..20fe0bf4f83f29d2821c0144a1be28d0a1e3f2eb 100644
--- a/core/modules/block_content/config/optional/views.view.block_content.yml
+++ b/core/modules/block_content/config/optional/views.view.block_content.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_block_content_view.yml b/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_block_content_view.yml
index ac4c9c500a9bd98a1c790263be577ea75c7cf3e8..bd7a6e40a7a8d6d6b1c63712316ab1c84b19ffb3 100644
--- a/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_block_content_view.yml
+++ b/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_block_content_view.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_field_filters.yml b/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_field_filters.yml
index 073cee86de6c2b3c94c3bfa8ae0ad0bcfc49466a..45eb3af060ad47fda92c91cecdb1a9f5da346734 100644
--- a/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_field_filters.yml
+++ b/core/modules/block_content/tests/modules/block_content_test_views/test_views/views.view.test_field_filters.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/book/tests/modules/book_test_views/test_views/views.view.test_book_view.yml b/core/modules/book/tests/modules/book_test_views/test_views/views.view.test_book_view.yml
index 7490892b5fa6b65b467e4f5edfc1e972ca6011b2..3aeb3a6cb7e67a9ed3c38d804a4f94d141476ad5 100644
--- a/core/modules/book/tests/modules/book_test_views/test_views/views.view.test_book_view.yml
+++ b/core/modules/book/tests/modules/book_test_views/test_views/views.view.test_book_view.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_field_name.yml b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_field_name.yml
index d18a41c95fb62c5c51867201bb853cae78722b44..db8aedd99337a3ff1f43fa120749702be4311ff2 100644
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_field_name.yml
+++ b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_field_name.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_operations.yml b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_operations.yml
index bda4dfb5b62260f997fca41f59b4ea3a49b2f20d..2537700cd4007f566c5306aec3881127c1159403 100644
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_operations.yml
+++ b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_operations.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_rest.yml b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_rest.yml
index fcc2526ed880c86e282c58fc195dfab62e4d97e4..fabd46c9e2546f4c8df672a33fa0076aa54c80c4 100644
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_rest.yml
+++ b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_rest.yml
@@ -42,7 +42,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_row.yml b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_row.yml
index 03ee3829d487abceeb8a04b90ccb9fceea33f758..0b36ef8084ed148f84e367a52e69110e41644ee0 100644
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_row.yml
+++ b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_row.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml
index 5cb79eecc76a1807acf11dd6aff2c5d1a0e25805..76c67c6b9595fdd8f213106eb6e3d500fe5991be 100644
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml
+++ b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/contact/tests/modules/contact_test_views/test_views/views.view.test_contact_link.yml b/core/modules/contact/tests/modules/contact_test_views/test_views/views.view.test_contact_link.yml
index d96ac75002d90f2b114694292193772e948f55e3..efc2109206c28b9ea85d2567ba52006d299eb88b 100644
--- a/core/modules/contact/tests/modules/contact_test_views/test_views/views.view.test_contact_link.yml
+++ b/core/modules/contact/tests/modules/contact_test_views/test_views/views.view.test_contact_link.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.latest.yml b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.latest.yml
index 491e2231ee05c2eb808862d0686d2a5fbb114c24..62e972e7dd3ed39bf525f6c43219aaa16f36ba63 100644
--- a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.latest.yml
+++ b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.latest.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_base_table_test.yml b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_base_table_test.yml
index 016b5b84aa717b4b90c9b5d123106147be2c9369..343806f90f5ad3340875b4b1ffd769be4ef51f87 100644
--- a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_base_table_test.yml
+++ b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_base_table_test.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_latest_revision.yml b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_latest_revision.yml
index 69dad0c33a47885a8e630045f968453a4f5e8d57..4727efa28d87e7dfd546cfe82060109682462eed 100644
--- a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_latest_revision.yml
+++ b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_latest_revision.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_revision_test.yml b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_revision_test.yml
index 99c9218e1e10c8f0f070c8a62fa025b642cd0a13..78fca3827317a14f280c2bb9cee621e403643dc5 100644
--- a/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_revision_test.yml
+++ b/core/modules/content_moderation/tests/modules/content_moderation_test_views/config/install/views.view.test_content_moderation_revision_test.yml
@@ -36,7 +36,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/field/tests/fixtures/update/views.view.entity_reference_plugins_2429191.yml b/core/modules/field/tests/fixtures/update/views.view.entity_reference_plugins_2429191.yml
index 53268517f757fb19bb00c65a2a2bca88e353fac3..9c49011ff9084adba3b157c4db51e98b0ac04060 100644
--- a/core/modules/field/tests/fixtures/update/views.view.entity_reference_plugins_2429191.yml
+++ b/core/modules/field/tests/fixtures/update/views.view.entity_reference_plugins_2429191.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/language/tests/language_test/config/optional/views.view.no_entity_translation_view.yml b/core/modules/language/tests/language_test/config/optional/views.view.no_entity_translation_view.yml
index 4b4af8be89f1efe9169f882a74952efbca104596..8e7ef450289bfc1145bd07390e09fecd0f4a040b 100644
--- a/core/modules/language/tests/language_test/config/optional/views.view.no_entity_translation_view.yml
+++ b/core/modules/language/tests/language_test/config/optional/views.view.no_entity_translation_view.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/link/tests/modules/link_test_views/test_views/views.view.test_link_tokens.yml b/core/modules/link/tests/modules/link_test_views/test_views/views.view.test_link_tokens.yml
index e3abd5f7fd8854c0014943cbf369c7c2251f0617..8f3ee26ea051f43f628364a065345aeaaaeda9aa 100644
--- a/core/modules/link/tests/modules/link_test_views/test_views/views.view.test_link_tokens.yml
+++ b/core/modules/link/tests/modules/link_test_views/test_views/views.view.test_link_tokens.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/config/optional/views.view.archive.yml b/core/modules/node/config/optional/views.view.archive.yml
index 40b6e56c79f95fb776b74af83baf85678a6a84d2..73e0477532558f568f2107bf0ed2fa89fe42b66f 100644
--- a/core/modules/node/config/optional/views.view.archive.yml
+++ b/core/modules/node/config/optional/views.view.archive.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/config/optional/views.view.content_recent.yml b/core/modules/node/config/optional/views.view.content_recent.yml
index 0767b0a69c143c9d38fd07fc8a2787d628e1cce1..39f4ecbad61508e54b9e549b9ee38418ff352c53 100644
--- a/core/modules/node/config/optional/views.view.content_recent.yml
+++ b/core/modules/node/config/optional/views.view.content_recent.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/config/optional/views.view.frontpage.yml b/core/modules/node/config/optional/views.view.frontpage.yml
index 81a5ffd48d30a1f2aa88f61c50673fad7fdf2fdf..d05e291987bcec0663f6a84a46e3410dd22daf23 100644
--- a/core/modules/node/config/optional/views.view.frontpage.yml
+++ b/core/modules/node/config/optional/views.view.frontpage.yml
@@ -63,7 +63,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/config/optional/views.view.glossary.yml b/core/modules/node/config/optional/views.view.glossary.yml
index ca17caa9a379ff6514af1845c508f30b0f0887e7..2b4e3301004726295f42c63eeb466898e3e9ee38 100644
--- a/core/modules/node/config/optional/views.view.glossary.yml
+++ b/core/modules/node/config/optional/views.view.glossary.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml
index b4b013c4fd228c231bd7703c84552221f9d1ce97..fcfc4f096ccbe3d63ae5b55a273d6c33a80349fa 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_filter_node_access.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_filter_node_access.yml
index 546d04115cc6a0e1e0989971a4e96afea2929b41..6663fa8261c1bd8bf145f3d4e15bb9a938895fbf 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_filter_node_access.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_filter_node_access.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_language.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_language.yml
index ae1f43e600cd89f7f67e3359296a3d3b7530b0b0..d95efc0615e17fdd555a550985f584c35dfbb9d3 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_language.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_language.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_nid_argument.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_nid_argument.yml
index 785415924206e2ed61c4dab65aeccdc90d0fff6f..f521093716937d6bf855f5e66cd54f6b4ce817e2 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_nid_argument.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_nid_argument.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_path_plugin.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_path_plugin.yml
index 509f7b68e34d322139c187d78e1394c11e815c9d..747de35781c90966a72485f2cd4d715aa0b31128 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_path_plugin.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_path_plugin.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_revision_links.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_revision_links.yml
index 6d4b3b845060ba3250a4883e6579db846c7cfe4f..1313f0140e9fb1666d4af57d2eeaa6a8813705ed 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_revision_links.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_revision_links.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_tokens.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_tokens.yml
index c45d78ac4db659bbf080500d89b7b612303ba764..26517fc2188820af6a7600af81ad2a1d570a9bcf 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_tokens.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_tokens.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_view.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_view.yml
index 32949cda1f25cbb8e39f6c2eccdbec138bb4393f..2fa9717872442b16c4a0232915aaefc21db5209a 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_view.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_view.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_numeric.yml b/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_numeric.yml
index 668ff9ff2e3000298cfaf6691cc2a9ce6d4f3aa8..bff9b597c511004484bf5cfcecc57782d3827961 100644
--- a/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_numeric.yml
+++ b/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_numeric.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_string.yml b/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_string.yml
index 11f5bf0f41cd23b50d56d1d61c7eee3349493b8b..1576619e8141e328529f133ac3edfd74770e8bfb 100644
--- a/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_string.yml
+++ b/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_argument_string.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_filter.yml b/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_filter.yml
index a487ca451c6122bbbe67b34447e8f12a40666853..7dd2602289fdf3c34885a9b6a66a048f5ff4a010 100644
--- a/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_filter.yml
+++ b/core/modules/options/tests/options_test_views/test_views/views.view.test_options_list_filter.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/rest/tests/modules/rest_test_views/test_views/views.view.test_excluded_field_token_display.yml b/core/modules/rest/tests/modules/rest_test_views/test_views/views.view.test_excluded_field_token_display.yml
index bbed0876b42e062fc319024e1e180995a4b1c172..e95f9533709d6455190699f1c3e7b23f9a26b630 100644
--- a/core/modules/rest/tests/modules/rest_test_views/test_views/views.view.test_excluded_field_token_display.yml
+++ b/core/modules/rest/tests/modules/rest_test_views/test_views/views.view.test_excluded_field_token_display.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/system/tests/fixtures/update/drupal-8.views-entity-views-data-2455125.yml b/core/modules/system/tests/fixtures/update/drupal-8.views-entity-views-data-2455125.yml
index eff6645f3e4c58880db933d9cf90498bdbf16699..e3c1b630fe167bb7abc38788d87ef305ad740c14 100644
--- a/core/modules/system/tests/fixtures/update/drupal-8.views-entity-views-data-2455125.yml
+++ b/core/modules/system/tests/fixtures/update/drupal-8.views-entity-views-data-2455125.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_mul_view.yml b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_mul_view.yml
index beff8c30a199edf16b7211eacde782939781ab5d..0d06377baab23cfb76b6ffac6621db4d5836b5f5 100644
--- a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_mul_view.yml
+++ b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_mul_view.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view.yml b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view.yml
index 6e93637b7dd28cfe0c7c1751e53960430e8b0b4e..5c9bc5f9489d336e82408f363da0c93f84628f78 100644
--- a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view.yml
+++ b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view_long.yml b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view_long.yml
index ab00ac16a461b9a4e79d0aae1659ec2655091175..9978205749d69839f8a9a09072535ffb5a20cbd0 100644
--- a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view_long.yml
+++ b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_entity_test_view_long.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_mul_view.yml b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_mul_view.yml
index 106b793e85248d15a19f5cc67a512882cfd1febc..a1153b66dc1598743a1e078046d4d4a96829a117 100644
--- a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_mul_view.yml
+++ b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_mul_view.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_view.yml b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_view.yml
index ce657c6c96a2b346c2bf61e0775a03f629270876..1412b71421a6f1c11a9e601f1da0d7256945a961 100644
--- a/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_view.yml
+++ b/core/modules/system/tests/modules/entity_reference_test_views/test_views/views.view.test_entity_reference_reverse_entity_test_view.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/config/optional/views.view.taxonomy_term.yml b/core/modules/taxonomy/config/optional/views.view.taxonomy_term.yml
index 3fdae2a8f3aa4cbc814fa2a58d53100694d53998..95b54a8a55244753c6fd8e9bb625826bfd3554bc 100644
--- a/core/modules/taxonomy/config/optional/views.view.taxonomy_term.yml
+++ b/core/modules/taxonomy/config/optional/views.view.taxonomy_term.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_all_terms_test.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_all_terms_test.yml
index 4338c7e999c7971546f9af23ea788aee70d80c7b..4f1467b9ed05affe70e12f4fa1ebec43a03cee9a 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_all_terms_test.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_all_terms_test.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
index 69d0c2be8e7c05b04985e64711e04b84b9abe903..d19e3955a776045f52cfa959fc1c61c9281d7e55 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_index_tid_depth.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_index_tid_depth.yml
index 73a874f4c068a8a1e75fb82e8600b1553968e93d..e6fd1a5d19264db7e5b16f367ced1a910d8050dc 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_index_tid_depth.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_index_tid_depth.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_vocabulary.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_vocabulary.yml
index b206af5346f3a9d7d708687726b076e2ccd7257e..a90e618f411acf394bea151f32e82790442ebbb2 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_vocabulary.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_argument_taxonomy_vocabulary.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_field_filters.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_field_filters.yml
index b6faae00d7053623db8bc75d5ccc87bf44f6935b..b2a7c9ed810254cf5a2520106e327f834b370ada 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_field_filters.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_field_filters.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid.yml
index 7657c56ead3d05079d1f91539fc034e503a2e8c0..ab5e1d896820bff6ca8885f8f32cc0121ec3903e 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid__non_existing_dependency.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid__non_existing_dependency.yml
index 640ab9a7e7e50bfbd030ea6d06a2f77d544a5fdc..a5c5828c2b31c3b3451bbec4e4c250136b0eb00c 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid__non_existing_dependency.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid__non_existing_dependency.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid_depth.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid_depth.yml
index 6731895af65ec305699e01011a737eb8d7c85da1..856543adc85a900ba9b7a8b3151fa9d278b17481 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid_depth.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid_depth.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_parent.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_parent.yml
index 02d3b6f86d57c1943761adf746d82e6c85b308ed..256f6189913c1bc5ff845ccf91168cb7058c0563 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_parent.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_parent.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_name.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_name.yml
index 3d684e154d2ac204d58e64c01e85fa1cb273da46..fbb91428fb66bd14e8ff484bd76540e893e20330 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_name.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_name.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_relationship.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_relationship.yml
index 2264dabebc86e520f743db386bc3b9c6c5803f5a..80295b6ea2498b9eac1098848a4cb65cd4a10ef6 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_relationship.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_term_relationship.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_tid_field.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_tid_field.yml
index edbbdc2bdc93160a36677024ecb4107f37257243..d54e4b4432c18dd3ba481805dd04b23dbf8bfca3 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_tid_field.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_tid_field.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/user/config/optional/views.view.who_s_new.yml b/core/modules/user/config/optional/views.view.who_s_new.yml
index 02a5a448c5ae3b19fc66d466ca605bcb03698e81..7d4ed34a8e88fb848c930421417b23d387ca3d96 100644
--- a/core/modules/user/config/optional/views.view.who_s_new.yml
+++ b/core/modules/user/config/optional/views.view.who_s_new.yml
@@ -36,7 +36,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/user/config/optional/views.view.who_s_online.yml b/core/modules/user/config/optional/views.view.who_s_online.yml
index 6ccc9cf58ba7289e6260eb070f48b73186028551..31160361a6cc7d63725f8adf5b073e225e5fdc64 100644
--- a/core/modules/user/config/optional/views.view.who_s_online.yml
+++ b/core/modules/user/config/optional/views.view.who_s_online.yml
@@ -36,7 +36,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_bulk_form_combine_filter.yml b/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_bulk_form_combine_filter.yml
index 5b280ea732d36237554b10c1f35696f6ba908835..075b4f6d9926fea7254aeedacfcdc9a315dba296 100644
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_bulk_form_combine_filter.yml
+++ b/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_bulk_form_combine_filter.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_roles_rid.yml b/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_roles_rid.yml
index 86cfbe2dbe5996a31a20341308db81f1ef458c41..ac67048a5dbb4cf93645695fc3287c709368ea7c 100644
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_roles_rid.yml
+++ b/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_roles_rid.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/src/Form/ViewsExposedForm.php b/core/modules/views/src/Form/ViewsExposedForm.php
index 372d963bf958af6451860cac22fffa6edb5191fc..bacd554954ee1ed1114d830f90d3fc935e7c2717 100644
--- a/core/modules/views/src/Form/ViewsExposedForm.php
+++ b/core/modules/views/src/Form/ViewsExposedForm.php
@@ -107,7 +107,7 @@ public function buildForm(array $form, FormStateInterface $form_state) {
       // Prevent from showing up in \Drupal::request()->query.
       '#name' => '',
       '#type' => 'submit',
-      '#value' => $this->t('Filter'),
+      '#value' => $this->t('Apply'),
       '#id' => Html::getUniqueId('edit-submit-' . $view->storage->id()),
     );
 
diff --git a/core/modules/views/src/Plugin/views/exposed_form/ExposedFormPluginBase.php b/core/modules/views/src/Plugin/views/exposed_form/ExposedFormPluginBase.php
index 16e2cd18d7e87b5b9f633be0f2a75329c66abe0b..4a2bc81d036c5ba6d47325832d6362c1433f9ef2 100644
--- a/core/modules/views/src/Plugin/views/exposed_form/ExposedFormPluginBase.php
+++ b/core/modules/views/src/Plugin/views/exposed_form/ExposedFormPluginBase.php
@@ -26,7 +26,7 @@ abstract class ExposedFormPluginBase extends PluginBase implements CacheableDepe
    */
   protected function defineOptions() {
     $options = parent::defineOptions();
-    $options['submit_button'] = array('default' => $this->t('Filter'));
+    $options['submit_button'] = array('default' => $this->t('Apply'));
     $options['reset_button'] = array('default' => FALSE);
     $options['reset_button_label'] = array('default' => $this->t('Reset'));
     $options['exposed_sorts_label'] = array('default' => $this->t('Sort by'));
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.base_and_revision.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.base_and_revision.yml
index 6b2db8eb2d72b749e3ed93589460be1b70793e94..d7d616297f56151095fb322ac4617fa11783d5f5 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.base_and_revision.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.base_and_revision.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.node_id_argument.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.node_id_argument.yml
index d163e519fd98f780e72b13e77b4b553c8d384474..5d2f5edab6980ceeca34e77e82a630f7ae2007c3 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.node_id_argument.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.node_id_argument.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.numeric_test.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.numeric_test.yml
index d5230eb63ecfdf170b34c1620b081e40dc2111d8..1246f1c708a0d5462e598a9e98815da2143a5d1b 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.numeric_test.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.numeric_test.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.rest_export_with_authorization.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.rest_export_with_authorization.yml
index b15d5e6152ad0999267bdd38143f6766c4c580bb..bef857f0a55d174521d8d7320cf74bc2e4ec324b 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.rest_export_with_authorization.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.rest_export_with_authorization.yml
@@ -42,7 +42,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_default_node.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_default_node.yml
index 3544bd94e758477c657c3bbdf71c1f0bea4bf05b..396e79877371079d53559f7d3257f70a3e4571f2 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_default_node.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_default_node.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_dependency.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_dependency.yml
index 43197f7719d20ae5cb9ca7e3d5ef54402425e991..2c8541b9f8f1f6ee9591478e5cce273cd8ba703e 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_dependency.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_dependency.yml
@@ -45,7 +45,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_validator_term.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_validator_term.yml
index 2227a6c9bd31f0a8f9b567eb7dcad0bb98979dee..91e239b0980968b8c9398bad032df28186f95894 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_validator_term.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_validator_term.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_attached_disabled.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_attached_disabled.yml
index e4bb2b86f03ca186fd1b800c46d3a92ac4f80e8c..c36cd48000b520537254655f771b3d9b256a0441 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_attached_disabled.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_attached_disabled.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_disabled_display.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_disabled_display.yml
index c325db42963cee000c95ab08114641e2dbb135e2..79abcdb932d00d819a730881152809dc1375e25b 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_disabled_display.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_disabled_display.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_duplicate_field_handlers.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_duplicate_field_handlers.yml
index d9f8cbab1c5e2dd1ea9d638f26517125d53cd7d4..41a9dfa0c4752bbdb3169ea4fb15ec46e0f456a6 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_duplicate_field_handlers.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_duplicate_field_handlers.yml
@@ -39,7 +39,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_link.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_link.yml
index f8ba53cc400e7758758dab0cd217213821d76336..ca151de45bc3aeb42f751f1b12299fb591382840 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_link.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_link.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_protected_access.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_protected_access.yml
index 512c87d41fadacdd7caf1daf81a21af04ced3e7e..024b12f82632c52699a398398c20f70bf3d84016 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_protected_access.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_test_protected_access.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_relationship_admin_ui.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_relationship_admin_ui.yml
index b46bc3c31d2291d47fe5c159081ef9b3a80408b9..7d5fb3f857a3901ddd9cc3d93730f7a5c1639001 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_relationship_admin_ui.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_relationship_admin_ui.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_feed_icon.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_feed_icon.yml
index 56765277787e0937513fa91da82e83da0a485f39..acb6acb0a26f8c6a82d38ab50ddc4b35fa9afd41 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_feed_icon.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_feed_icon.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_body.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_body.yml
index a8ac1d6a666189501e93298443a200e5b0c92c44..60d3cede22161e222f46b2e8eab0b48f492ed556 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_body.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_body.yml
@@ -40,7 +40,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_entity_test_rendered.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_entity_test_rendered.yml
index b8e1936bdaf99852ba4966c40a08fd5f295fe8ae..541ee969306fd6c9efc62c1057f8988eac093ede 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_entity_test_rendered.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_entity_test_rendered.yml
@@ -36,7 +36,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_field_attachment_test.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_field_attachment_test.yml
index 24e76e8ee94563f437196cd2f5776ee48722bab5..e09726426b4016dd01bc225d8e2f503eb36c1133 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_field_attachment_test.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_field_attachment_test.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_glossary.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_glossary.yml
index b687bb9aecd2e17c5a8ebe8f546f98e138168c68..e2e143eafc2bdf288b705d3f974a0c8e4d2e8183 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_glossary.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_glossary.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache.yml
index 26ec9ed594ce36913d77aa3cc3c7340254f5f798..34a3cc56b8aaab27361bc176bcc09781403f8629 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache_none.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache_none.yml
index 5abfa111a683d76a6fa853edd7921737a1e0ed0c..3a6bf953be25b78e39111b1fede61e13396ba8e9 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache_none.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_row_render_cache_none.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_search.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_search.yml
index 5b5f60e51400ada3cd716668ef78906ec9e08b4b..67873caf086679739c8a3fc9b60da7fe6af7afb8 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_search.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_search.yml
@@ -38,7 +38,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_taxonomy_glossary.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_taxonomy_glossary.yml
index 3b396cc0c36bdbcd1dd35971e74d1ff9a3f7a8d1..8e4182dc16e55795849cf77360a12e21af6dbace 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_taxonomy_glossary.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_taxonomy_glossary.yml
@@ -35,7 +35,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_token_view.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_token_view.yml
index 8c85d59c3ae6952ad8c8ca8ffb8c394b1a5e9528..b2e3c7d58b68657a3aa1aae41508aa2355168c39 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_token_view.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_token_view.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views_ui/tests/modules/views_ui_test/config/install/views.view.sa_contrib_2013_035.yml b/core/modules/views_ui/tests/modules/views_ui_test/config/install/views.view.sa_contrib_2013_035.yml
index 014f865ab1c311d5512e0cfc09a8ea031aa57d14..d45d509c5c7815cb2835422bb5938abc8c992497 100644
--- a/core/modules/views_ui/tests/modules/views_ui_test/config/install/views.view.sa_contrib_2013_035.yml
+++ b/core/modules/views_ui/tests/modules/views_ui_test/config/install/views.view.sa_contrib_2013_035.yml
@@ -37,7 +37,7 @@ display:
       exposed_form:
         type: basic
         options:
-          submit_button: Filter
+          submit_button: Apply
           reset_button: false
           reset_button_label: Reset
           exposed_sorts_label: 'Sort by'
diff --git a/core/modules/views/src/Tests/Plugin/ExposedFormTest.php b/core/modules/views/src/Tests/Plugin/ExposedFormTest.php
index 93553739855eab18b285688d81fa7cc843118045..b51129cf4c871d7c5fff5cca19543517e2368b9b 100644
--- a/core/modules/views/src/Tests/Plugin/ExposedFormTest.php
+++ b/core/modules/views/src/Tests/Plugin/ExposedFormTest.php
@@ -50,10 +50,10 @@ protected function setUp() {
    * Tests the submit button.
    */
   public function testSubmitButton() {
     // Test the submit button value defaults to 'Filter'.
     $this->drupalGet('test_exposed_form_buttons');
     $this->assertResponse(200);
-    $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', t('Filter'));
+    $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', t('Apply'));
 
     // Rename the label of the submit button.
     $view = Views::getView('test_exposed_form_buttons');
@@ -68,7 +68,7 @@ public function testSubmitButton() {
     $this->drupalGet('test_exposed_form_buttons');
     $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', $expected_label);
 
     // Make sure an empty label uses the default 'Filter' button value too.
     $view = Views::getView('test_exposed_form_buttons');
     $view->setDisplay();
 
@@ -77,9 +77,9 @@ public function testSubmitButton() {
     $view->display_handler->setOption('exposed_form', $exposed_form);
     $view->save();
 
     // Make sure the submit button label shows 'Filter'.
     $this->drupalGet('test_exposed_form_buttons');
-    $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', t('Filter'));
+    $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', t('Apply'));
   }
 
   /**
@@ -296,7 +296,7 @@ public function testInputRequired() {
 
     $this->drupalGet('test_exposed_form_buttons');
     $this->assertResponse(200);
-    $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', t('Filter'));
+    $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', t('Apply'));
 
     // Ensure that no results are displayed.
     $rows = $this->xpath("//div[contains(@class, 'views-row')]");
@@ -408,14 +408,14 @@ public function testFormErrorWithExposedForm() {
     $this->assertResponse(200);
     $form = $this->cssSelect('form.views-exposed-form');
     $this->assertTrue($form, 'The exposed form element was found.');
-    $this->assertRaw(t('Filter'), 'Ensure the exposed form is rendered before submitting the normal form.');
+    $this->assertRaw(t('Apply'), 'Ensure the exposed form is rendered before submitting the normal form.');
     $this->assertRaw('<div class="views-row">', 'Views result shown.');
 
     $this->drupalPostForm(NULL, array(), t('Submit'));
     $this->assertResponse(200);
     $form = $this->cssSelect('form.views-exposed-form');
     $this->assertTrue($form, 'The exposed form element was found.');
-    $this->assertRaw(t('Filter'), 'Ensure the exposed form is rendered after submitting the normal form.');
+    $this->assertRaw(t('Apply'), 'Ensure the exposed form is rendered after submitting the normal form.');
     $this->assertRaw('<div class="views-row">', 'Views result shown.');
   }
 
@@ -50,10 +50,10 @@ protected function setUp() {
    */
   public function testSubmitButton() {
-    // Test the submit button value defaults to 'Filter'.
+    // Test the submit button value defaults to 'Apply'.
     $this->drupalGet('test_exposed_form_buttons');
     $this->assertResponse(200);
@@ -68,7 +68,7 @@ public function testSubmitButton() {
     $this->helperButtonHasLabel('edit-submit-test-exposed-form-buttons', $expected_label);
 
-    // Make sure an empty label uses the default 'Filter' button value too.
+    // Make sure an empty label uses the default 'Apply' button value too.
     $view = Views::getView('test_exposed_form_buttons');
     $view->setDisplay();
@@ -77,9 +77,9 @@ public function testSubmitButton() {
     $view->save();
 
-    // Make sure the submit button label shows 'Filter'.
+    // Make sure the submit button label shows 'Apply'.
     $this->drupalGet('test_exposed_form_buttons');